@@ -156,7 +156,7 @@ class rcube_cache
      * @param boolean $prefix_mode Enable it to clear all keys starting
      *                             with prefix specified in $key
      */
-    public function remove($key=null, $prefix_mode=false)
+    public function remove($key = null, $prefix_mode = false)
     {
         // Remove all keys
         if ($key === null) {
@@ -232,6 +232,33 @@ class rcube_cache
         $this->cache_changes = array();
     }
 
+    /**
+     * A helper to build cache key for specified parameters.
+     *
+     * @param string $prefix Key prefix (Max. length 64 characters)
+     * @param array  $params Additional parameters
+     *
+     * @return string Key name
+     */
+    public static function key_name($prefix, $params = array())
+    {
+        $cache_key = $prefix;
+
+        if (!empty($params)) {
+            $func   = function($v) {
+                if (is_array($v)) {
+                    sort($v);
+                }
+                return is_string($v) ? $v : serialize($v);
+            };
+
+            $params = array_map($func, $params);
+            $cache_key .= '.' . md5(implode(':', $params));
+        }
+
+        return $cache_key;
+    }
+
     /**
      * Reads cache entry.
      *
